@@ -88,11 +88,16 @@ instaprint = tweaks.instaprint
 _defaults = dict(
     dark_theme_qt         = False,
     dark_theme_figures    = False,
+    font_size             = 12,
     font_size_legend      = 9,
-    font_size_axis_labels = 12,
-    font_size_title       = 10,)
+    font_size_title       = 12,)
 
 for _k in _defaults: 
     if not _k in settings.keys(): settings[_k] = _defaults[_k]
+    
+# Plot stuff
+pylab.rcParams.update({
+    'font.size' : settings['font_size']
+    })
 
 
