@@ -344,13 +344,13 @@ def format_figure(figure=None, tall=False, draw=True, modify_geometry=True):
         axes.title.set_size(8)
         axes.title.set_position([1.5,1.02])
         axes.title.set_visible(1)
-        axes.title.set_fontsize(_s.settings['font_size_title'])
+        axes.title.set_fontsize(_s.settings['font_size'])
         #axes.yaxis.label.set_horizontalalignment('center')
         #axes.xaxis.label.set_horizontalalignment('center')
         
         # Axes labels
-        axes.xaxis.label.set_fontsize(_s.settings['font_size_axis_labels'])
-        axes.yaxis.label.set_fontsize(_s.settings['font_size_axis_labels'])
+        axes.xaxis.label.set_fontsize(_s.settings['font_size'])
+        axes.yaxis.label.set_fontsize(_s.settings['font_size'])
 
     _pylab.axes(current_axes)
 
